==> ejc-sale-impl-3.0.0-20220419.090228-47-sources.jar: com/ejianc/business/sale/controller/SignfreightController.java <==
package com.ejianc.business.sale.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.sale.bean.SignfreightdetailEntity;
import com.ejianc.business.sale.vo.PaymentdetialVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.sale.bean.SignfreightEntity;
import com.ejianc.business.sale.service.ISignfreightService;
import com.ejianc.business.sale.vo.SignfreightVO;

/**
 * 运费签认单
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("signfreight")
public class SignfreightController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISignfreightService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SignfreightVO> saveOrUpdate(@RequestBody SignfreightVO saveOrUpdateVO) {
    	SignfreightEntity entity = BeanMapper.map(saveOrUpdateVO, SignfreightEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setPaymentStatus(1);
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                for(SignfreightdetailEntity signfreightdetailEntity : entity.getSignfreightdetailList()){
                    signfreightdetailEntity.setId(null);
                }
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        if(saveOrUpdateVO.getSignfreightdetailList().size() == 0){
            throw new BusinessException("销售运费已确认信息为空,不允许保存!");
        }
    	service.saveOrUpdate(entity, false);
    	SignfreightVO vo = BeanMapper.map(entity, SignfreightVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SignfreightVO> queryDetail(Long id) {
    	SignfreightEntity entity = service.selectById(id);
    	SignfreightVO vo = BeanMapper.map(entity, SignfreightVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SignfreightVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SignfreightVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SignfreightVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SignfreightVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<SignfreightEntity> page = service.queryPage(param,false);
        IPage<SignfreightVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SignfreightVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SignfreightEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Signfreight-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refSignfreightData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SignfreightVO>> refSignfreightData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<SignfreightEntity> page = service.queryPage(param,false);
        IPage<SignfreightVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SignfreightVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
    /**
     * @Description queryList 根据运输商id查询改运输商上个月的运费情况
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/signfreightList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<PaymentdetialVO>> signfreightList(@RequestBody QueryParam param) {

        QueryWrapper<SignfreightEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("transport_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("transport_id",param.getParams().get("transport_id").getValue());
        }
        queryWrapper.in("payment_status",1,2);
        List<SignfreightEntity> list = service.list(queryWrapper);
        List<PaymentdetialVO> paymentdetialVO = new ArrayList<>();
        for(SignfreightEntity signfreightEntity : list){
            PaymentdetialVO paymentdetiallist = new PaymentdetialVO();
            paymentdetiallist.setId(signfreightEntity.getId());
            paymentdetiallist.setBillCode(signfreightEntity.getBillCode());
            paymentdetiallist.setPaymentMoney(signfreightEntity.getSignMoney());
            paymentdetiallist.setPaidMoney(new BigDecimal(0.00));
            if(signfreightEntity.getPaymentMoney().doubleValue() != 0.00){
                paymentdetiallist.setOtherPaidMoney(signfreightEntity.getPaymentMoney());
            }else{
                paymentdetiallist.setOtherPaidMoney(new BigDecimal(0.00));
            }
            paymentdetiallist.setOutstandingMoney(signfreightEntity.getNotPaymentMoney());
            paymentdetiallist.setRowState("add");
            paymentdetialVO.add(paymentdetiallist);
        }

        return CommonResponse.success("查询列表数据成功！",paymentdetialVO);
    }
}

==> ejc-sale-impl-3.0.0-20220502.092958-73-sources.jar: com/ejianc/business/sale/controller/SignfreightController.java <==
package com.ejianc.business.sale.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.sale.bean.SignfreightdetailEntity;
import com.ejianc.business.sale.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.sale.bean.SignfreightEntity;
import com.ejianc.business.sale.service.ISignfreightService;

/**
 * 运费签认单
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("signfreight")
public class SignfreightController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISignfreightService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SignfreightVO> saveOrUpdate(@RequestBody SignfreightVO saveOrUpdateVO) {
    	SignfreightEntity entity = BeanMapper.map(saveOrUpdateVO, SignfreightEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setPaymentStatus(1);
                entity.setPaymentMoney(new BigDecimal(0.00));
                entity.setNotPaymentMoney(entity.getSignMoney());
                entity.setOpeninvoiceStatus(1);
                entity.setOpeninvoiceMoney(new BigDecimal(0.00));
                entity.setNotOpeninvoiceMoney(entity.getSignMoney());
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
                for(SignfreightdetailEntity signfreightdetailEntity : entity.getSignfreightdetailList()){
                    signfreightdetailEntity.setId(null);
                }
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        if(saveOrUpdateVO.getSignfreightdetailList().size() == 0){
            throw new BusinessException("销售运费已确认信息为空,不允许保存!");
        }
    	service.saveOrUpdate(entity, false);
    	SignfreightVO vo = BeanMapper.map(entity, SignfreightVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SignfreightVO> queryDetail(Long id) {
    	SignfreightEntity entity = service.selectById(id);
    	SignfreightVO vo = BeanMapper.map(entity, SignfreightVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SignfreightVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SignfreightVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SignfreightVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SignfreightVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("transportName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<SignfreightEntity> page = service.queryPage(param,false);
        IPage<SignfreightVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SignfreightVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SignfreightEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Signfreight-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refSignfreightData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SignfreightVO>> refSignfreightData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<SignfreightEntity> page = service.queryPage(param,false);
        IPage<SignfreightVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SignfreightVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
    /**
     * @Description queryList 根据运输商id查询改运输商上个月的运费情况
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/signfreightList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<PaymentdetialVO>> signfreightList(@RequestBody QueryParam param) {

        QueryWrapper<SignfreightEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("transport_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("transport_id",param.getParams().get("transport_id").getValue());
        }
        queryWrapper.in("payment_status",1,2);
        List<SignfreightEntity> list = service.list(queryWrapper);
        List<PaymentdetialVO> paymentdetialVO = new ArrayList<>();
        for(SignfreightEntity signfreightEntity : list){
            PaymentdetialVO paymentdetiallist = new PaymentdetialVO();
            paymentdetiallist.setId(signfreightEntity.getId());
            paymentdetiallist.setBillCode(signfreightEntity.getBillCode());
            paymentdetiallist.setPaymentMoney(signfreightEntity.getSignMoney());
            paymentdetiallist.setPaidMoney(new BigDecimal(0.00));
            if(signfreightEntity.getPaymentMoney().doubleValue() != 0.00){
                paymentdetiallist.setOtherPaidMoney(signfreightEntity.getPaymentMoney());
            }else{
                paymentdetiallist.setOtherPaidMoney(new BigDecimal(0.00));
            }
            paymentdetiallist.setOutstandingMoney(signfreightEntity.getNotPaymentMoney());
            paymentdetiallist.setManualshipmentId(signfreightEntity.getId());
            paymentdetiallist.setRowState("add");
            paymentdetialVO.add(paymentdetiallist);
        }

        return CommonResponse.success("查询列表数据成功！",paymentdetialVO);
    }

    /**
     * @Description queryList 根据运输商id查询未开票或者部分开票信息
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/openinvoiceList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<OpeninvoicedetialVO>> openinvoiceList(@RequestBody QueryParam param) {

        QueryWrapper<SignfreightEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("transport_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("transport_id",param.getParams().get("transport_id").getValue());
        }
        queryWrapper.in("openinvoice_status",1,2);
        List<SignfreightEntity> list = service.list(queryWrapper);
        List<OpeninvoicedetialVO> openinvoicedetialVO = new ArrayList<>();
        for(SignfreightEntity signfreightEntity : list){
            OpeninvoicedetialVO openinvoicedetialList = new OpeninvoicedetialVO();
            openinvoicedetialList.setId(signfreightEntity.getId());
            openinvoicedetialList.setBillCode(signfreightEntity.getBillCode());
            openinvoicedetialList.setOpenInvoiceMoney(signfreightEntity.getSignMoney());
            openinvoicedetialList.setReimbursedMoney(new BigDecimal(0.00));
            if(signfreightEntity.getOpeninvoiceMoney().doubleValue() != 0.00){
                openinvoicedetialList.setOtherReimbursedMoney(signfreightEntity.getOpeninvoiceMoney());
            }else{
                openinvoicedetialList.setOtherReimbursedMoney(new BigDecimal(0.0));
            }
            openinvoicedetialList.setNotReimbursedMoney(signfreightEntity.getNotOpeninvoiceMoney());
            openinvoicedetialList.setSignfreightId(signfreightEntity.getId());
            openinvoicedetialList.setRowState("add");
            openinvoicedetialVO.add(openinvoicedetialList);
        }

        return CommonResponse.success("查询列表数据成功！",openinvoicedetialVO);
    }
}
